package cribbage;

import java.util.LinkedList;
import java.util.List;
import java.util.Scanner;

/** A class to represent the cards a player plays during the play phase. **/
public class PlayHand {
    private List<Card> unplayed;
    private List<Card> played;
    
    public PlayHand(List<Card> cards) {
        unplayed = new LinkedList<Card>(cards);
        played = new LinkedList<Card>();
    }
    
    public boolean hasCards() {
        return unplayed.size() > 0;
    }
    
    /** Given a limit on the highest point card that can be
     *  played without putting the count over 31, determine
     *  if any cards are left that can be played. */
    public boolean canPlayCard(int limit) {
        for(Card c : unplayed) {
            if(c.getPoints() <= limit)
                return true;
        }
        return false;
    }
    
    /** Implements the play strategy for the computer player.
     *  Tries to play every card that won't put the count over
     *  31 and then returns the card that would yield the highest
     *  number of points. */
    public Card autoPlay(PlayPile pile) {
        int maxPoints = -1;
        Card best = null;
        for(Card c : unplayed) {
            if(c.getPoints() <= pile.getLimit()) {
                int points = pile.tryCard(c);
                if(points > maxPoints) {
                    maxPoints = points;
                    best = c;
                }
            }
        }
        if(best != null) {
             unplayed.remove(best);
            played.add(best);
        }
        return best;
    }
    
    /** Prompts the player to choose a card to play. **/
    public Card playerPlay(int limit) {
        Scanner input = new Scanner(System.in);
        int k = 0;
        while(k < 1 || k > unplayed.size()) {
            System.out.println("Select a card to play:");
            for(int n = 0; n < unplayed.size(); n++) {
                Card c = unplayed.get(n);
                if(c.getPoints() <= limit)
                    System.out.println((n+1) + ") " + unplayed.get(n));
            }
            k = input.nextInt();
        }
        Card card = unplayed.get(k-1);
        unplayed.remove(k-1);
        played.add(card);
        return card;
    }
}
