package cribbage;

import java.util.ArrayList;

/** Represents the sequence of cards that have been played in the
 *  play phase. **/
public class PlayPile {
    private ArrayList<Card> played;
    private Card starter;
    private int count;
    
    public PlayPile() {
        played = new ArrayList<Card>();
        count = 0;
    }
    
    public int getCount() { 
        return count;
    }
    
    public int getLimit() {
        return 31 - count;
    }
    
    /** If the given card gets played, how many points would it be worth? **/
    public int tryCard(Card card) {
        int points = 0;
        
        int tempCount = count;
        tempCount += card.getPoints();
        
        if(tempCount == 15) {
            points = 2;
        } else if(tempCount == 31) {
            points = 2;
        }
           
        // Check for n of a kind at the end of the sequence
        int pairCount = 0;
        int n = played.size() - 1;
        while(n > 0 && played.get(n).getFace() == card.getFace()) {
            pairCount++;
            n--;
        }
        if(pairCount == 1) {
            points += 2;
        } else if(pairCount == 2) {
            points += 6;
        } else if(pairCount == 3) {
            points += 12;
        }
          
        // Check for runs at the end of the sequence
        int runCount = 0;
        int k = 1;
        n = played.size() - k;
        while(n > 0 && played.get(n).getFace().ordinal() - k == card.getFace().ordinal()) {
            runCount++;
            n--;
            k++;
        }
        if(runCount >= 3) {
            points += runCount;
        }
        
        return points;
    }
    
    /** Play the give card and return how many points it is worth. **/
    public int playCard(Card card) {
        int points = 0;
        
        count += card.getPoints();
        
        if(count == 15) {
            points = 2;
            System.out.println("15 for 2");
        } else if(count == 31) {
            points = 2;
            System.out.println("31 for 2");
        }
           
        int pairCount = 0;
        int n = played.size() - 1;
        while(n > 0 && played.get(n).getFace() == card.getFace()) {
            pairCount++;
            n--;
        }
        if(pairCount == 1) {
            points += 2;
            System.out.println("Pair for 2");
        } else if(pairCount == 2) {
            points += 6;
            System.out.println("Three of a kind for 6");
        } else if(pairCount == 3) {
            points += 12;
            System.out.println("Four of kind for 12");
        }
          
        int runCount = 0;
        int k = 1;
        n = played.size() - k;
        while(n > 0 && played.get(n).getFace().ordinal() - k == card.getFace().ordinal()) {
            runCount++;
            n--;
            k++;
        }
        if(runCount >= 3) {
            points += runCount;
            System.out.println("Run of " + runCount + " for " + runCount);
        }
        
        played.add(card);
        if(count == 31) {
            played.clear();
            count = 0;
        }
            
        return points;
    }
}
